<?php

	lt_include( PLOG_CLASS_PATH."class/plugin/pluginbase.class.php" );
	
	define( "POST_STATUS_EXTERNAL_SUBMISSION", 200 );
	
	/**
	 * allows users to submit posts to the blog, and keeps them in a separate queue
	 */
	class PluginSubmissions extends PluginBase
	{
	
		function PluginSubmissions($source = "")
		{
			$this->PluginBase($source);
			
			$this->id = "submissions";
			$this->desc = "Allows visitors to submit stories to the blog.";
			$this->author = "The LifeType Project";
			$this->version = "20111027";
			
			if( $source == "admin" )
				$this->initAdmin();
			else
				$this->init();
		}
		
		/**
		 * registers all the filters and actions that we're going to use
		 */
		function init(){			
		    // action to show the form to add a new story
		    $this->registerBlogAction( "submissionForm", "ShowSubmissionFormAction" );
		    $this->registerBlogAction( "submitStory", "AddSubmissionAction" );
		}

		/**
		 * registers all the filters and actions that we're going to use on the admin side
		 */
		function initAdmin(){			
			$this->registerAdminAction( "submissionsPluginSettings", "AdminSubmissionsPluginSettingsAction" );
			$this->registerAdminAction( "pluginSubmissionsUpdateSettings", "AdminSubmissionsPluginUpdateSettingsAction" );
			
			// add a couple of menu entries
			//$this->addMenuEntry( "/menu/Manage/managePosts", "submissionsPluginSettings", "admin.php?op=submissionsPluginSettings", "submissionsPluginSettings", array(), array("plugin_submission"), false );
			$this->addMenuEntry( "/menu/Manage/managePosts", "submissionsPluginSettings", "admin.php?op=submissionsPluginSettings", "", true, false );
		}
        
		function register()
		{
		    $blogSettings = $this->blogInfo->getSettings();
		    $this->pluginEnabled = $blogSettings->getValue( "plugin_submissions_enabled" );
		    $this->htmlareaEnabled = $blogSettings->getValue( "plugin_submissions_htmlarea_enabled" );
		    $this->notificationsEnabled = $blogSettings->getValue( "plugin_submissions_notifications_enabled" );
	    }
	    
	    function isEnabled()
	    {
	        return $this->pluginEnabled;
	    }

	    function isHtmlareaEnabled()
	    {
	        return $this->htmlareaEnabled;
	    }

	    function isNotificationsEnabled()
	    {
	        return $this->notificationsEnabled;
	    }

        function pluginTemplatePage($categoryId = "")
        {
            lt_include( PLOG_CLASS_PATH."class/net/rawrequestgenerator.class.php" );	
 			$rg = new RawRequestGenerator($this->blogInfo);
            
        	$rg->addParameter( "op", "submissionForm" );
            $rg->addParameter( "blogId", $this->blogInfo->getId());
            if($categoryId)
                $rg->addParameter( "categoryId", $categoryId);
            
            $templatePage = $rg->getIndexUrl().$rg->getRequest();

            return $templatePage;
        }
        
        function getPluginConfigurationKeys(){

            return (Array(
                        Array("name" => "plugin_submissions_enabled",
                              "type" => "boolean"),
                        Array("name" => "plugin_submissions_htmlarea_enabled",
                              "type" => "boolean"),
                        Array("name" => "plugin_submissions_notifications_enabled",
                              "type" => "boolean"),
                        Array("name" => "plugin_submissions_require_name",
                              "type" => "boolean")
                        ));
        }	
	}  
?>
